==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/el/admin/users/general.php <==
<?php


return array(
    'activated_help_text' => 'This user can login',
    'activated_disabled_help_text' => 'You cannot edit activation status for your own account.',
    'assets_user'       => 'Περιουσιακά στοιχεία που έχει αντιστοιχιστεί σε: όνομα',
    'bulk_update_warn'	=> 'Πρόκειται να επεξεργαστείτε τις ιδιότητες των χρηστών: user_count. Λάβετε υπόψη ότι δεν μπορείτε να αλλάξετε τα δικά σας χαρακτηριστικά χρήστη χρησιμοποιώντας αυτήν τη φόρμα και πρέπει να κάνετε αλλαγές στον δικό σας χρήστη ξεχωριστά.',
    'bulk_update_help'	=> 'Αυτή η φόρμα σας επιτρέπει να ενημερώσετε ταυτόχρονα πολλούς χρήστες. Συμπληρώστε μόνο τα πεδία που πρέπει να αλλάξετε. Τα τυχόν κενά πεδία παραμένουν αμετάβλητα.',
    'current_assets'    => 'Περιουσιακά στοιχεία που ελέγχονται αυτήν τη στιγμή σε αυτόν τον χρήστη',
    'clone'             => 'Κλώνος χρήστη',
    'contact_user'      => 'Επικοινωνία :Όνομα',
    'edit'              => 'Επεξεργασία χρήστη',
    'filetype_info'     => 'Επιτρεπόμενοι τύποι αρχείων είναι png, gif, jpg, jpeg, doc, docx, pdf, txt, zip και rar.',
    'history_user'      => 'Ιστορικό: όνομα',
	'info'				=> 'Πληροφορίες',
    'restore_user'		=> 'Κάντε κλικ εδώ για να τα επαναφέρετε.',
    'last_login'        => 'Τελευταία σύνδεση',
    'ldap_config_text'  => 'Οι ρυθμίσεις διαμόρφωσης LDAP μπορούν να βρεθούν στο στοιχείο Διαχειριστής> Ρυθμίσεις. Η (επιλεγμένη) επιλεγμένη τοποθεσία θα οριστεί για όλους τους εισαγόμενους χρήστες.',
    'print_assigned'    => 'Print All Assigned',
    'software_user'     => 'Λογισμικό Έγινε έλεγχος σε: όνομα',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Προβολή χρήστη :ονόματος',
    'usercsv'           => 'CSV αρχείο',
    'two_factor_admin_optin_help' => 'Οι τρέχουσες ρυθμίσεις διαχειριστή επιτρέπουν την επιλεκτική εφαρμογή ελέγχου ταυτότητας δύο παραγόντων.',
    'two_factor_enrolled' => 'Συσκευή εγγραφής 2FA',
    'two_factor_active'   => '2FA Active',
    );

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/el/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'This user can login',
    'activated_disabled_help_text' => 'You cannot edit activation status for your own account.',
    'assets_user'       => 'Περιουσιακά στοιχεία που έχει αντιστοιχιστεί σε: όνομα',
    'bulk_update_warn'	=> 'Πρόκειται να επεξεργαστείτε τις ιδιότητες των χρηστών: user_count. Λάβετε υπόψη ότι δεν μπορείτε να αλλάξετε τα δικά σας χαρακτηριστικά χρήστη χρησιμοποιώντας αυτήν τη φόρμα και πρέπει να κάνετε αλλαγές στον δικό σας χρήστη ξεχωριστά.',
    'bulk_update_help'	=> 'Αυτή η φόρμα σας επιτρέπει να ενημερώσετε ταυτόχρονα πολλούς χρήστες. Συμπληρώστε μόνο τα πεδία που πρέπει να αλλάξετε. Τα τυχόν κενά πεδία παραμένουν αμετάβλητα.',
    'current_assets'    => 'Περιουσιακά στοιχεία που ελέγχονται αυτήν τη στιγμή σε αυτόν τον χρήστη',
    'clone'             => 'Κλώνος χρήστη',
    'contact_user'      => 'Επικοινωνία :Όνομα',
    'edit'              => 'Επεξεργασία χρήστη',
    'filetype_info'     => 'Επιτρεπόμενοι τύποι αρχείων είναι png, gif, jpg, jpeg, doc, docx, pdf, txt, zip και rar.',
    'history_user'      => 'Ιστορικό: όνομα',
    'info'				=> 'Πληροφορίες',
    'restore_user'		=> 'Κάντε κλικ εδώ για να τα επαναφέρετε.',
    'last_login'        => 'Τελευταία σύνδεση',
    'ldap_config_text'  => 'Οι ρυθμίσεις διαμόρφωσης LDAP μπορούν να βρεθούν στο στοιχείο Διαχειριστής> Ρυθμίσεις. Η (επιλεγμένη) επιλεγμένη τοποθεσία θα οριστεί για όλους τους εισαγόμενους χρήστες.',
    'print_assigned'    => 'Print All Assigned',
    'software_user'     => 'Λογισμικό Έγινε έλεγχος σε: όνομα',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Προβολή χρήστη :ονόματος',
    'usercsv'           => 'CSV αρχείο',
    'two_factor_admin_optin_help' => 'Οι τρέχουσες ρυθμίσεις διαχειριστή επιτρέπουν την επιλεκτική εφαρμογή ελέγχου ταυτότητας δύο παραγόντων.',
    'two_factor_enrolled' => 'Συσκευή εγγραφής 2FA',
    'two_factor_active'   => '2FA Active',
    'user_deactivated'  => 'User is de-activated',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion' => 'WARNING:',
    'warning_deletion_information' => 'You are about to delete the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_asssets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
];
